#
# spec file for package tiled
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tiled
Version:        1.1.5
Release:        lp150.1.1
Summary:        A tilemap editor
License:        GPL-2.0+
Group:          Productivity/Graphics/Other
Url:            http://www.mapeditor.org
Source:         https://github.com/bjorn/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5OpenGL-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  shared-mime-info
BuildRequires:  zlib-devel
Recommends:     tmxtools
Provides:       tiled-qt

%description
Tiled is a general purpose tile map editor. It is built to work with
varying game engines, whether your game is an RPG, platformer or
Breakout clone. Tiled is written in C++, using the Qt application
framework.

%package -n tmxtools
Summary:        Commandline Tools for Tiled MapEditor
License:        BSD-2-Clause
Group:          Productivity/Graphics/Other

%description -n tmxtools
This package contains tmxviewer, a simple application to view Tiled maps
and tmxrasterizer which is also a command line tool.

%package -n libtiled1
Summary:        Library for Tiled MapEditor
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++

%description -n libtiled1
This package contains libtiled a library for the Tiled map editor.

%prep
%setup -q
# Remove copy of zlib
rm -rf src/zlib

%build
qmake-qt5 -r PREFIX=%{_prefix} LIBDIR=%{_libdir} RPATH=no USE_FHS_PLUGIN_PATH=yes

make %{?_smp_mflags}

%install
make install INSTALL_ROOT=%{buildroot}

# Clean build artefacts
find -name ".uic" -or -name ".moc" -or -name ".rcc" | xargs rm -rf

# locale files
%find_lang %{name} --with-qt

# Removed development file (this version does not install headers anyway)
rm %{buildroot}%{_libdir}/lib%{name}.so

# Remove duplicates
%fdupes %{buildroot}%{_datadir}

# Install software gallery metadata
install -Dm0644 tiled.appdata.xml %{buildroot}%{_datadir}/appdata/tiled.appdata.xml

%post -n libtiled1 -p /sbin/ldconfig
%postun -n libtiled1 -p /sbin/ldconfig

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun
%endif

%files -f %{name}.lang
%doc AUTHORS NEWS.md README.md COPYING LICENSE.GPL LICENSE.BSD
%{_bindir}/%{name}
%{_bindir}/terraingenerator
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/mimetypes/application-x-%{name}.*
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/mime/packages/%{name}.xml
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/translations
%{_libdir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%files -n libtiled1
%doc LICENSE.BSD
%{_libdir}/lib%{name}.so.*

%files -n tmxtools
%doc LICENSE.BSD
%{_bindir}/automappingconverter
%{_bindir}/tmxrasterizer
%{_bindir}/tmxviewer
%{_mandir}/man1/tmxviewer.1%{ext_man}
%{_mandir}/man1/tmxrasterizer.1%{ext_man}
%{_mandir}/man1/automappingconverter.1%{ext_man}
%dir %{_datadir}/thumbnailers/
%{_datadir}/thumbnailers/tiled.thumbnailer
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/tiled.appdata.xml

%changelog
* Thu Apr 26 2018 mvetter@suse.com
- Update to 1.1.5:
  * Fixed erasing mode of the Terrain Brush
  * Fixed crash after editing a template
  * Fixed rendering of eye/lock icons in Layers view
  * Fixed object index when undoing Move Object to Layer action (#1932[1])
  * Fixed shortcuts for flipping and rotating objects (#1926[2])
  * Fixed dynamic retranslation of tools and tool actions
  * Fixed possible crash when undoing/redoing Wang color changes
  * Fixed handling of sub-properties in Object Type Editor (#1936[3])
  * Fixed crash when deleting an object right before dragging it (#1933[4])
  * Adjust Wang tile data when tileset column count changes (#1851[5])
  * Improved fill behavior in case of selection on infinite map (#1921[6])
  * Removed ability to hide tile collision objects (#1929[7])
  * Remove tile collision layer along with the last object (#1230[8])
  * JSON plugin: Made the reader more strict about object types (#1922[9])
  * JSON plugin: Added support for Wang sets
* Wed Mar 28 2018 mvetter@suse.com
- Update to 1.1.4:
  * Fixed exporting of external tilesets to JSON or TSX formats
  * Fixed problem with embedding or exporting tilesets with Wang sets
  * Fixed tiles placed by the terrain tool being considered different (#1913[1])
  * Fixed text alignment values appearing at random in Properties view (#1767[2])
  * Re-enabled Space for toggling layer visibility
  * Migrate properties set on tile collision layer to the tile (#1912[3])
  * Don't reset stamp brush state when pressing Alt
  * Automapping: Apply rules to selected area when there is one
  * Windows and Linux: Updated builds to Qt 5.10.1
  * Linux: Indicate Tiled can open multiple files at once in desktop file
  * Lowered the minimum supported version of Qt to 5.5
* Wed Mar  7 2018 mvetter@suse.com
- Update to 1.1.3:
  * Fixed crash when removing a tileset referenced by multiple objects
  * Fixed crash on paste when it introduced more than one new tileset
  * Fixed Invert Selection for non-infinite maps
  * Fixed Select All to not select objects on locked layers
  * Fixed logic determining the tilesets used by a tile layer
  * Fixed copy/paste changing object order (#1896[1])
  * Fixed tileset getting loaded twice when used by the map and a template
  * Fixed repainting issues on undo/redo for new maps (#1887[2])
  * JSON plugin: Fixed loading of infinite maps using CSV tile layer format (#1878[3])
  * Updated Hungarian, Japanese, Norwegian Bokmål, Portuguese and Ukrainian translations
* Wed Jan 31 2018 mvetter@suse.com
- Update to 1.1.2:
  * Fixed possible crash while editing polygons
  * Fixed hang when loading map file with empty compressed layer data
  * Fixed selection of tile stamp to work on mouse click
  * Fixed tools not being up to date on modifier keys after activation
  * Fixed "Offset Map" action for infinite maps (#1866)
  * Templates view: Keep template centered when resizing view
  * Tile Collision Editor: Keep tile centered when resizing view
  * Tile Collision Editor: Display tool info text in status bar
  * JSON plugin: Fixed reading of infinite maps (#1858)
  * libtiled-java: Fixed some bugs (by Henry Wang, #1840)
  * libtiled-java: Fixed tile offset value not being considered (by digitalhoax, #1863)
- Remove upstreamed tiled-1.1.0-empty-return.patch
* Fri Jan  5 2018 mvetter@suse.com
- Update to 1.1.1:
  * Fixed crash on load for template instances of non-tile objects
* Thu Jan  4 2018 mvetter@suse.com
- Update to 1.1.0:
  * Added support for infinite maps (by Ketan Gupta, #260)
  * Added support for Wang tiles and related tools (by Benjamin Trotter)
  * Added support for reusable object templates (by Mohamed Thabet)
  * Added icon for animation editor in the tileset editor (by Ketan Gupta, #1706)
  * Added ability to reorder terrain types (by Justin Jacobs, #1603)
  * Added support for custom input formats and TMX output to the --export-map command-line option
  * Added island RPG example based on Beach tileset by finalbossblues
  * Added file-related context menu actions to tileset tabs
  * Added support for exporting tilesets, including to Lua format (by Conrad Mercer, #1213)
  * Improved polygon node handles and drag behavior
  * Fixed %%executablepath variable for executables found in PATH (#1648)
  * Fixed Delete key to delete selected polygon nodes when appropriate (by Ketan Gupta, #1555)
  * Fixed crash when saving two new maps using the same file name (#1734)
  * Fixed selection rectangle's shadow offset when zooming (by Antoine Gersant, #1796)
  * Fixed potential crash after deleting object or group layers
  * Automapping: Don't fail if an input/inputnot layer isn't found
  * Automapping: Added a "StrictEmpty" flag to input layers
  * GMX plugin: Added support for defining views with objects (by William Taylor, #1621)
  * GMX plugin: Start counting default tile layer depth from 1000000 (#1814)
  * tBIN plugin: Added read/write support for the tBIN map format (by Chase Warrington, #1560)
  * libtiled-java: Generate classes from XSD, some fixes and build with Maven (by Mike Thomas, #1637)
  * libtiled-java: Added support for manipulating non-consecutive tile IDs in a tileset (by Stéphane Seng)
  * Python plugin: Adjusted example scripts to API changes (by spiiin, #1769)
  * plugin: Various changes (by Justin Jacobs, #1781)
  * TMW plugin: Removed since it is no longer needed
  * Updated translations
- Add tiled-1.1.0-empty-return.patch: Fix 'Program returns random data in a function'
* Tue Aug 29 2017 mvetter@suse.com
- Update to 1.0.3:
  * Fixed crash on reload map (#1659[1], #1694[2])
  * Fixed possible crash on undo/redo in collision editor (#1695[3])
  * Fixed tile replacement to add tileset when needed (by Mohamed Thabet, #1641[4])
  * Fixed the display of the image source property for tilesets
  * Fixed shortcut for 'Copy tile coordinates' (Alt+C) in Portuguese translation (by olueiro)
  * JSON plugin: Fixed reading of tileset column count
  * JSON plugin: Fixed reading of custom properties on tile collision object group
* Wed Jun 14 2017 mvetter@suse.com
- Update to 1.0.1:
  * Made the zoom level used in Tilesets view persistent
  * Fixed mixed up polygon and polyline icons (by Ketan Gupta, #1588[1])
  * Fixed reset of font size when using font dialog (#1596[2])
  * Fixed several issues with the Properties dock (#1583[3], #1611[4])
  * Fixed centering on object on layer with offset (#1600[5])
  * Fixed handling of symbolic links in Recent Files menu and Maps view (#1589[6])
  * Fixed labels for objects in grouped object layers
  * Reverted the file format version back to "1.0" and added "tiledversion" attribute
  * Lua plugin: Fixed group layers being exported with "imagelayer" type (#1595[7])
  * Added Korean translation (by miru2533 and SshipSunBee, #1604[8])
  * Updated Russian and Chinese translations
* Fri May 26 2017 mvetter@suse.com
- Update to 1.0.0:
  * Added support for editing external tilesets (#242)
  * Added a text object with configurable font and wrapping (#1429)
  * Added layer grouping (#1038)
  * Added Tile.type and inherit tile object properties from the tile (#436, #1248)
  * Added a start page
  * Added selection of underlying objects with Alt modifier (by Yuriy, #1491)
  * Added an option to disable safe writing of files (#1402, #1404)
  * Added invert selection action (by Leon Moctezuma, #1423)
  * Added support for isometric terrain overlays and tile collision objects (#419, #757)
  * Added 180-degree symmetry mode to terrain brush with Alt modifier
  * Added short and consistent map format names to use with --export-map (by Marce Coll, #1382)
  * Added Swap Tiles action (by Alexander Münch, #866)
  * Added tileset background color property (#227)
  * Added 60 degree tile rotation support for hexagonal maps (by Victor Nicolaichuk, #1447)
  * Added a check for duplicates when adding tiles (by Simião, #1227)
  * Added option to run commands from menu as well as edit them (by Ketan Gupta, #943)
  * Added custom shortcuts for commands (by Ketan Gupta, #1456)
  * Added optional ID and Position columns to objects view (by i-ka, #1462)
  * Added an executable picker for custom commands (by Ketan Gupta, #942)
  * Added marching ants effect on selected objects (by Mohamed Thabet, #1489)
  * Added all open tilesets to the Tilesets view
  * Added auto-show/hide all views (Clear View) action (by erem2k, #563)
  * Added minimap in the resizing dialog (by Yuriy, #1516)
  * Added drag-n-drop support in Layers view (#178)
  * Added support for storing object type definitions in JSON format (#1313)
  * Added cut/copy/paste actions for custom properties (#515)
  * Allow changing the tile of tile objects (by Mohamed Thabet, #409)
  * Allow selecting a folder to fix multiple broken links at once
  * Added support for dragging external tilesets into the Tilesets dock
  * Added support for dragging images into image collection tilesets
  * Write out Tiled version in TMX/JSON “version” attribute (#1416)
  * Remember last view on map also for closed files (#905)
  * Remember tileset zoom level in the tileset editor (by Artem Sharganov, #408)
  * Change current layer depending on selected objects (by Glavak, #1424)
  * Improved support for using Tiled on HiDpi screens
  * Improved the behavior of the tile selection tool
  * Made Ctrl+D duplicate objects instead of deleting them
  * Use an eye icon instead of a checkbox for layer visibility (by Ketan Gupta, #1127)
  * JSON tileset: Save width/height of individual tile images
  * Linux: Added MIME type for tileset files
  * Fixed hexagonal rotation of tile stamps (by Bdtrotte, #1476)
  * Fixed handling of broken tile references, which now render as a red marker
  * Fixed manual reloading of images for image collection tilesets
  * Fixed Offset Layers tool to wait until mouse is moved
  * Fixed current stamp to always update when a tile is clicked
  * Fixed handling of pinch gestures (#1305)
  * Fixed flipping a group of objects to work like expected (by Vitek1425, #1475)
  * Fixed stamp brush to work better on staggered maps (by Bdtrotte)
  * Fixed objects offsetting while resizing (by Acuion, #1518)
  * Fixed fill tool for hexagonal maps (#883)
  * Fixed potential crash in Terrain Brush
  * Windows: Fixed menus when using OpenGL in full screen mode (#1576)
  * Windows: Added Sticker Knight and Python example scripts to installer (#819)
  * Windows: Fixed bringing existing Tiled window to foreground (#1256)
  * AutoMapping: Fixed object groups always getting added
  * AutoMapping: Improved map boundary handling (by Stefan Beller, #1224)
  * AutoMapping: Apply custom properties set on output layers
  * terraingenerator: Made the amount of columns configurable
  * terraingenerator: Copy tile properties from the source tilesets
  * Added Ukrainian translation (by Olexandr Nesterenko)
  * Added Hungarian translation (by Balázs Úr)
  * Added Finnish translation (by ekeimaja)
  * Updated Bulgarian, Dutch, French, German, Russian, Spanish and Turkish translations
* Tue Mar  7 2017 mvetter@suse.com
- Update to 0.18.2:
  * Fixed crash when deleting multiple selected objects
  * Fixed crash when moving multiple selected objects to another object layer
  * Fixed updating of values displayed in Objects and Layers views
  * GmxPlugin: Added support for image collection tilesets
  * Object Types Editor: Improved behavior when adding new types
  * Linux: Fixed shipping of image format plugins in AppImage releases
* Thu Feb  2 2017 jengelh@inai.de
- Trim filler words from description
* Fri Jan 27 2017 mvetter@suse.com
- Update to 0.18.1:
  * Fixed terrain brush for isometric staggered maps (by Clyde)
  * Fixed crash when resizing map causes objects to get removed
  * Fixed crash when duplicating an object layer
  * Fixed position of image layer after Resize or Offset Map
  * Fixed the quality of the minimap on HiDpi displays
  * Fixed Alt-drag behavior to not override resize handles
  * When adding a new layer, insert it above the current one
  * GmxPlugin: Fixed positioning for non-tile objects and support scaling
  * GmxPlugin: Export tile objects without a type as tiles
  * GmxPlugin: Support horizontal and vertical flipping
  * Updated Chinese translation (by Clyde)
* Tue Dec 20 2016 mvetter@suse.com
- Fix plugin detection:
  We need USE_FHS_PLUGIN_PATH=yes so tiled finds the plugins and
  doesn't look relative to the executables path.
  Without this exporting to lua, json etc never worked.
* Tue Dec 20 2016 mvetter@suse.com
- Update to version 0.18.0:
  * Added Layer via Copy/Cut actions
  * Added support for Paste in Place action for tile layers
  * Added context menu to change custom property type (by Dmitry Hrabrov)
  * Added support for higher precision for custom floating point properties
  * Added %%mappath variable to commands (by Jack Roper)
  * Added snapping to pixels (by Mamed Ibrahimov)
  * Added right-click to clear the tile selection
  * Added a context menu action to reset the size of tile objects
  * Added exporter for Game Maker Studio room files (by Jones Blunt)
  * Added Move Up/Down buttons to Objects view (by iskolbin)
  * Added pixel coordinates to status bar for object tools (by iskolbin)
  * Added Sticker Knight platformer example (by Ponywolf)
  * tmxrasterizer: Added --size argument and support local file URLs
  * tmxrasterizer: Use smooth pixmap transform by default
  * Linux: Register tmxrasterizer as thumbnail generator for TMX files
  * Allow scrolling past map edges with mouse wheel
  * Enabled HiDpi scaling and improved the quality of some icons
  * Reversed the order of the objects in the Objects view
  * JSON plugin: Added Node.js support to the JavaScript export
  * Updated TMX schema definition (by assofohdz)
  * Fixed unfinished objects getting saved
  * Fixed OpenGL rendering mode when application is scaled (HiDpi screens)
  * Fixed Remove and Rename actions for predefined properties
  * Windows: Fixed console output
  * libtiled-java: Use Maven, deploy to OSSRH and code updates (by Mike Thomas)
  * libtiled-java: Added a basic isometric renderer (by Mike Thomas)
  * Updated Brazilian Portuguese, Chinese, Czech, Dutch, Hebrew, Norwegian Bokmål and Spanish translations
  See: http://discourse.mapeditor.org/t/tiled-0-18-0-released/1897
- Add tiled.thumbnailer
* Wed Oct 12 2016 mailaender@opensuse.org
- Add icon/desktop/mime macros
- Install appdata for https://en.opensuse.org/openSUSE:AppStore
- Update to version 0.17.0
  * Added a platform-independent theme, which can be dark (#786)
  * Added Paste in Place action for objects (#1257)
  * Added custom property type 'color' (#1275)
  * Added custom property type 'file' (#1278)
  * Added option for removing invisible objects in resize dialog (#1032, by Mamed Ibrahimov)
  * Added support for editing multi-line string properties (#205)
  * Added %%layername and %%objectid to available command variables
  * Added support for scrolling in tileset view with middle mouse button (#1050, with Will Luongo)
  * Added a rectangle erase mode to the eraser (#1297)
  * Added export to Defold .tilemap files (#1316, by Nikita Razdobreev)
  * Added simple full screen mode
  * Added "Copy File Path" and "Open Containing Folder" actions to tab context menu
  * Added warning when saving with the wrong file extension
  * Added color picker for setting transparent color of a tileset (#1173, by Ava Brumfield)
  * Various object selection tool improvements
  * Allow creating rectangle/ellipse objects in any direction (#1300)
  * Enabled nested views and grouped dragging for stacked views (#1291)
  * Fixed updating object drag cursor when exiting resize handles (#1277)
  * Fixed tile animations to stay in sync when changing them (#1288)
  * Fixed preservation of tile meta-data when tileset width is changed (#1315)
  * Updated Bulgarian, Dutch, German, Norwegian Bokmål, Russian, Spanish and Turkish translations
  * JSON plugin: Fixed loading of custom properties on terrains
  * Lua plugin: Fixed missing export of object layer drawing order
  * Fixed tile index adjustment when tileset image changes width
  * Fixed --export-map [format] option
  * Fixed shortcuts for some tools when language is set to Dutch
  * Fixed a painting related bug affecting the top edge after AutoMapping
* Fri May 13 2016 rpm@fthiessen.de
- Update to version 0.16.1
  * Bugfix release, some crashed are fixed.
* Mon May  2 2016 rpm@fthiessen.de
- Update to version 0.16.0
- Minor spec cleanup
* Wed Jun 17 2015 roman@priesol.net
- update to version 0.12.3
* Sun Jan  4 2015 bemyak@gmail.com
- update to version 0.10.2
* Wed Nov 13 2013 mailaender@opensuse.org
- update to version 0.9.1
- spec and file cleanup
- removed desktop file and icon (now included)
- https://en.opensuse.org/SourceUrls
- separated GUI tool, library and cli tools
* Tue Feb  5 2013 ablu.erikschilling@googlemail.com
- fixed qt4->qt
* Tue Feb  5 2013 ablu.erikschilling@googlemail.com
- Removed conflict line
* Fri Feb  1 2013 ablu.erikschilling@googlemail.com
- Added conflict line
* Mon Jan 28 2013 ablu.erikschilling@googlemail.com
- Added obsolete line
* Sat Jan 12 2013 ablu.erikschilling@googlemail.com
- New upstream release 0.9.0
- Dropped now obsolete patches and files
* Mon Sep  3 2012 ablu.erikschilling@googlemail.com
- Added note about which parts are licensed with which license.
- Made sure that the copy of zlib inside of the source is removed.
- Fixed handling of locales (using %%%%find_lang).
- Avoided plain asterisks in %%%%files.
- Made description clear about containing the tmxviewer.
* Sun Sep  2 2012 ablu.erikschilling@googlemail.com
- First version for official fedora repos.
* Fri May 11 2012 ablu.erikschilling@googlemail.com
- Copied package to obs, fixed problems occurring there.
